#!/bin/sh

#/***************************************************************************
#*                                                                          *
#*  OpenNI 2.0                                                              *
#*  Copyright (C) 2012 PrimeSense Ltd.                                      *
#*                                                                          *
#*  This file is part of OpenNI2 installation.                              *
#*                                                                          *
#*  OpenNI is free software: you can redistribute it and/or modify          *
#*  it under the terms of the GNU Lesser General Public License as published*
#*  by the Free Software Foundation, either version 3 of the License, or    *
#*  (at your option) any later version.                                     *
#*                                                                          *
#*  OpenNI is distributed in the hope that it will be useful,               *
#*  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
#*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the            *
#*  GNU Lesser General Public License for more details.                     *
#*                                                                          *
#*  You should have received a copy of the GNU Lesser General Public License*
#*  along with OpenNI. If not, see <http://www.gnu.org/licenses/>.          *
#*                                                                          *
#***************************************************************************/
#

# Check if user is root/running with sudo
if [ `whoami` != root ]; then
    echo Please run this script with sudo
    exit
fi

ORIG_PATH=`pwd`
cd `dirname $0`
SCRIPT_PATH=`pwd`
cd $ORIG_PATH

usage="
Usage: $0 [OPTIONS]
Installs OpenNI to current machine.

-i,--install
    Installs OpenNI (default mode)
-u,--uninstall
    Uninstalls OpenNI.
-h,--help
    Shows this help screen.
"
# parse command line
while [ "$1" ]; do
    case $1 in
    -i|--install)
        install=yes
        ;;
    -u|--uninstall)
        uninstall=yes
        ;;
    -h|--help)
        echo "$usage"
        exit 0
        ;;
    *)
        echo "Unrecognized option $1"
        exit 1
    esac
    shift
done
# default mode is install
if [ ! "$install" = yes ] && [ ! "$uninstall" = yes ]; then
    install=yes
fi

# validity check
if [ "$install" = yes ] && [ "$uninstall" = yes ]; then
    echo "-i and -u flags cannot be used together!"
    exit 1
fi
# Make Dir
INSTALL_TERABEE=$rootfs/usr/etc/TERABEE
INSTALL_TERABEE_LIB=$INSTALL_TERABEE/lib
mkdir -p $INSTALL_TERABEE_LIB
INSTALL_LIB=$rootfs/usr/lib

if [ "$install" = yes ]; then
    # detect Linux OS distribution
    printf "Detect OS distribution version and create links\n"
    DIST_ID=`lsb_release -i -s`
    DIST_RE=`lsb_release -r -s`
    DIST_CO=`lsb_release -c -s`
    if [ "$DIST_ID" = "Ubuntu" ]; then
        if [ "$DIST_RE" = "16.04" ] || [ "$DIST_RE" = "16.10" ] || [ "$DIST_RE" = "17.04" ] || [ "$DIST_RE" = "17.10" ]; then
            DIST_REL_NAME=16.04
        else
            DIST_REL_NAME=14.04
        fi
        printf "It's $DIST_ID $DIST_RE\n\n"
    elif [ "$DIST_ID" = "LinuxMint" ]; then
        if [ "$DIST_RE" = "17" ]; then
            DIST_REL_NAME=14.04
        elif echo "$DIST_RE" | grep -q "17.*"; then
            DIST_REL_NAME=14.04
        else
            DIST_REL_NAME=16.04
        fi
        printf "It's $DIST_ID $DIST_RE\n\n"
    elif [ "$DIST_ID" = "elementary" ]; then
        if [ "$DIST_RE" = "0.3" ]; then
            DIST_REL_NAME=14.04
        elif echo "$DIST_RE" | grep -q "0.3.*"; then
            DIST_REL_NAME=14.04
        else
            DIST_REL_NAME=16.04
        fi
        printf "It's $DIST_ID $DIST_RE\n\n"
    elif [ "$DIST_ID" = "Debian" ] || [ "$DIST_ID" = "Raspbian" ]; then
        if [ "$DIST_CO" = "stretch" ]; then
            DIST_REL_NAME=16.04
        else
            DIST_REL_NAME=14.04
        fi
    else
        #Let Ubuntu 16.04 as default distribution for install
        printf "Unknown, try default Ubutnu 16.04 build\n\n"
        DIST_REL_NAME=16.04
    fi

    # create file list
    TERABEE_CONF=`ls $SCRIPT_PATH/TERABEE/TERABEE/config/*.json`
    TERABEE_LIBS=`ls $SCRIPT_PATH/TERABEE/TERABEE/lib/$DIST_REL_NAME/lib*.so*`

    ln -sf $SCRIPT_PATH/TERABEE/TERABEE/lib/$DIST_REL_NAME/libbilateralfilter.so $SCRIPT_PATH/TERABEE/TERABEE/lib/libbilateralfilter.so
    ln -sf $SCRIPT_PATH/TERABEE/TERABEE/lib/$DIST_REL_NAME/libdevicesensor.so $SCRIPT_PATH/TERABEE/TERABEE/lib/libdevicesensor.so
    if [ -f "$SCRIPT_PATH/TERABEE/TERABEE/lib/$DIST_REL_NAME/libcudaproc.so" ]; then
        ln -sf $SCRIPT_PATH/TERABEE/TERABEE/lib/$DIST_REL_NAME/libcudaproc.so $SCRIPT_PATH/TERABEE/TERABEE/lib/libcudaproc.so
    fi
    if [ -f "$SCRIPT_PATH/TERABEE/TERABEE/lib/$DIST_REL_NAME/libclproc.so" ]; then
        ln -sf $SCRIPT_PATH/TERABEE/TERABEE/lib/$DIST_REL_NAME/libclproc.so $SCRIPT_PATH/TERABEE/TERABEE/lib/libclproc.so
    fi
    ln -sf $SCRIPT_PATH/Samples/Bin/OpenNI2/Drivers/$DIST_REL_NAME/libmodule-terabee2.so $SCRIPT_PATH/Samples/Bin/OpenNI2/Drivers/libmodule-terabee2.so
    ln -sf $SCRIPT_PATH/Tools/OpenNI2/Drivers/$DIST_REL_NAME/libmodule-terabee2.so $SCRIPT_PATH/Tools/OpenNI2/Drivers/libmodule-terabee2.so
    ln -sf $SCRIPT_PATH/Redist/OpenNI2/Drivers/$DIST_REL_NAME/libmodule-terabee2.so $SCRIPT_PATH/Redist/OpenNI2/Drivers/libmodule-terabee2.so

    if [ "`uname -s`" != "Darwin" ]; then
        # Install UDEV rules for USB device
        # TERABEE udev rules
        printf "copying TERABEE udev rules..."
        cp ${SCRIPT_PATH}/99-TERABEE-video.rules /etc/udev/rules.d/99-TERABEE-video.rules
        chmod a+r /etc/udev/rules.d/99-TERABEE-video.rules
        printf "OK..\n"

        # TERABEE libs: libdevicesensor, libbilateralfilter
        printf "copying TERABEE libraries..."
        for filename in $TERABEE_LIBS; do
            if [ -f $filename ]; then
                cp -pf $filename $INSTALL_TERABEE_LIB/
                cp -pf $filename $INSTALL_LIB/
            else
                # remember to remove previous installed libs from system
                [ -f $INSTALL_TERABEE_LIB/`basename $filename` ] && rm -f $INSTALL_TERABEE_LIB/`basename $filename`
                [ -f $INSTALL_LIB/`basename $filename` ] && rm -f $INSTALL_LIB/`basename $filename`
            fi
        done
        printf "OK\n"
		# support ROS (openni2)
		if [ -d $INSTALL_LIB/OpenNI2/Drivers ]; then
			#printf "found install folder /usr/lib/OpenNI2/Drivers/\n"
			[ -e $INSTALL_LIB/OpenNI2/Drivers/libmodule-terabee2.so ] && rm -f $INSTALL_LIB/OpenNI2/Drivers/libmodule-terabee2.so
			cp -pf $SCRIPT_PATH/Tools/OpenNI2/Drivers/libmodule-terabee2.so $INSTALL_LIB/OpenNI2/Drivers/libmodule-terabee2.so.0
			cd $INSTALL_LIB/OpenNI2/Drivers
			ln -sf libmodule-terabee2.so.0 libmodule-terabee2.so
			cd - > /dev/NULL
		fi

        #copy config file
        printf "copying TERABEE config..."
        cp -pf $TERABEE_CONF $INSTALL_TERABEE_LIB
        printf "OK\n"
    fi

    OUT_FILE="$SCRIPT_PATH/OpenNIDevEnvironment"

    echo "export OPENNI2_INCLUDE=$SCRIPT_PATH/Include" > $OUT_FILE
    echo "export OPENNI2_REDIST=$SCRIPT_PATH/Redist" >> $OUT_FILE
    chmod a+r $OUT_FILE

    printf "DONE...\n"
fi

if [ "$uninstall" = yes ]; then
    #TERABEE module
    printf "Removing TERABEE libraries..."
    for filename in $TERABEE_LIBS; do
        [ -f $INSTALL_TERABEE_LIB/`basename $filename` ] && rm -f $INSTALL_TERABEE_LIB/`basename $filename`
        [ -f $INSTALL_LIB/`basename $filename` ] && rm -f $INSTALL_LIB/`basename $filename`
    done
	# uninstall library for ROS
	[ -e /usr/lib/OpenNI2/Drivers/libmodule-terabee2.so ] && rm -f /usr/lib/OpenNI2/Drivers/libmodule-terabee2.so
	[ -e /usr/lib/OpenNI2/Drivers/libmodule-terabee2.so.0 ] && rm -f /usr/lib/OpenNI2/Drivers/libmodule-terabee2.so.0
    printf "OK\n"

	printf "Removing TERABEE config..."
    for configname in $TERABEE_CONF; do
        rm -f $INSTALL_TERABEE_LIB/`basename $configname`
    done

    printf "OK\n"

    rm -rf $INSTALL_TERABEE
    rm -f /etc/udev/rules.d/99-TERABEE-video.rules

    printf "DONE.....\n"
fi


